@@ -21,6 +21,7 @@ from pyg_base._pandas import df_index, df_columns, df_reindex, np_reindex, df_re
 from pyg_base._pandas import ts_deal_with_issue, ts_gap, ts_degap, df_drop_index_duplicates
 from pyg_base._perdictable import join, perdictable
 from pyg_base._reducer import reducer, reducing
+from pyg_base._roll import df_roll_off
 from pyg_base._sort import sort, cmp, Cmp
 from pyg_base._tree import is_tree, tree_to_table
 from pyg_base._tree_repr import tree_repr
@@ -28,10 +29,10 @@ from pyg_base._txt import alphabet, ALPHABET, f12, as_ascii, replace, relabel_lo
 from pyg_base._types import is_pd, is_arr, is_int, is_float, is_num, is_bool, is_str, is_nan, \
     is_none, is_dict, is_iterable, is_date, is_df, is_series, is_ts, is_list, is_tuple, is_regex, is_primitive, \
     is_pds, is_arrs, is_ints, is_floats, is_nums, is_len, is_bools, is_strs, is_nans, is_nones, is_dicts, is_zero_len, \
-    is_iterables, is_tss, nan2none, NoneType, is_dates, is_lists, list_instances
+    is_iterables, is_tss, nan2none, null2none, NoneType, is_dates, is_lists, list_instances
 from pyg_base._ulist import ulist, rng
 from pyg_base._waiter import waiter, async_wrapper
+from pyg_base._xls import pd_to_excel
 from pyg_base._zip import zipper, lens
-from pyg_base._roll import df_roll_off
 from pyg_npy import np_save, pd_to_npy, pd_read_npy, path_name, path_dirname, path_join, mkdir
 
